
from odoo.tests import tagged
from .common import HttpCaseWithUserPortalAndWirePayment


@tagged('post_install', '-at_install')
class TestPartnerDashboard(HttpCaseWithUserPortalAndWirePayment):

    def test_01_become_a_partner_schedule_meeting(self):
        self.start_tour("/", 'become_a_partner_schedule_meeting', login="portal")

    def test_02_become_a_partner_buy_learning(self):
        self._setup_payment_transfer_for_test()

        self.assertFalse(self.partner_portal.grade_id, "Portal should not have any grade yet")

        # Set default commission plan
        learning_grade = self.env.ref('openerp_portal.res_partner_grade_learning')
        learning_grade.default_commission_plan_id = self.env['commission.plan'].create({
            'name': "Learning Partner Commission Plan",
            'product_id': self.env.ref('partner_commission.product_commission').id,
        })

        # Let user buy a "Learning" grade partnership
        self.start_tour("/", 'become_a_partner_buy_learning', login="portal")
        self.assertFalse(self.partner_portal.grade_id)

        # Validate and confirm order
        order = self.env['sale.order'].search([], order='id DESC', limit=1)
        self.assertEqual(order.state, 'sent')
        self.assertEqual(order.partner_id, self.partner_portal, "Last order should be for Joel Willis")
        self.assertRecordValues(order.order_line, [
            {'product_id': self.env.ref('openerp_enterprise.odoo_learning_platform_access').id},
        ])
        order.action_confirm()

        # Create invoice and register payment
        invoice = order._create_invoices()
        invoice.action_post()
        self._register_payment(invoice)

        # Check that the partner has automatically been assigned to "Learning" level
        self.assertEqual(
            self.partner_portal.grade_id, learning_grade,
            "Upon payment of the 'Learning Partnership Fee', partner should be auto. assigned to that level",
        )
        self.assertEqual(self.partner_portal.commission_plan_id, learning_grade.default_commission_plan_id)

    def test_03_partner_dashboard_fill_profile_anonymous(self):
        self.start_tour("/", "partner_dashboard_fill_profile_anonymous", login=None)
